@@ -1,25 +1,15 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-VERSION = "1.16.0"
+VERSION = "1.17.0"
 
 import curses
 from datetime import datetime, timedelta
 from functools import wraps
 from math import ceil
-try:
-    from queue import Empty, Queue
-except ImportError:
-    from Queue import Empty, Queue
+from queue import Empty, Queue
 import re
 import os
 from os.path import abspath, dirname
-from subprocess import Popen, STDOUT
-try:
-    from subprocess import DEVNULL
-except ImportError:  # Python 2
-    DEVNULL = open(os.devnull, 'wb')
+from subprocess import DEVNULL, Popen, STDOUT
 from sys import exit, stderr, stdout
 from threading import Event, Lock, Thread
 from time import sleep
@@ -31,8 +21,6 @@ from dateutil.parser import parse
 from pyfiglet import CharNotPrinted, Figlet
 
 
-click.disable_unicode_literals_warning = True
-
 DEFAULT_FONT = "univers"
 DEFAULT_TIME_FORMAT = "%H:%M:%S"  # --no-seconds expects this to end with :%S
 TIMEDELTA_REGEX = re.compile(r'((?P<years>\d+)y ?)?'
@@ -45,6 +33,7 @@ INPUT_RESET = 2
 INPUT_EXIT = 3
 INPUT_LAP = 4
 INPUT_PLUS = 5
+INPUT_MINUS = 6
 
 
 def setup(stdscr):
@@ -424,6 +413,8 @@ def countdown(
                     continue
                 elif input_action == INPUT_PLUS:
                     target += timedelta(seconds=10)
+                elif input_action == INPUT_MINUS:
+                    target -= timedelta(seconds=10)
                 elif input_action == INPUT_LAP:
                     continue
 
@@ -633,6 +624,8 @@ def stopwatch(
                     seconds_elapsed = 0
                 elif input_action == INPUT_PLUS:
                     sync_start -= timedelta(seconds=10)
+                elif input_action == INPUT_MINUS:
+                    sync_start += timedelta(seconds=10)
                 elif input_action == INPUT_LAP:
                     if pause_start:
                         sync_start += (datetime.now() - pause_start)
@@ -669,6 +662,8 @@ def input_thread_body(stdscr, input_queue, quit_event, curses_lock):
             input_queue.put(INPUT_LAP)
         elif key == "+":
             input_queue.put(INPUT_PLUS)
+        elif key == "-":
+            input_queue.put(INPUT_MINUS)
         sleep(0.01)
 
 
@@ -738,6 +733,7 @@ def main(**kwargs):
     \tR\tReset
     \tSPACE\tPause (will delay absolute TIME)
     \t+\tPlus (will add 10 seconds)
+    \t-\tMinus (will subtract 10 seconds)
     \tQ\tQuit
     """
     if kwargs['time_format'] is None:
